==> DateTime-Locale-1.32.tar.gz: DateTime-Locale-1.32/share/es-CO.pl <==
{
  am_pm_abbreviated => [
    "a.\N{U+00a0}m.",
    "p.\N{U+00a0}m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM 'de' y G",
    GyMMMEd => "E, d MMM 'de' y G",
    GyMMMM => "MMMM 'de' y G",
    GyMMMMEd => "E, d 'de' MMMM 'de' y G",
    GyMMMMd => "d 'de' MMMM 'de' y G",
    GyMMMd => "d 'de' MMM 'de' y G",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "H:mm:ss v",
    Hmsvvvv => "H:mm:ss (vvvv)",
    Hmv => "H:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d 'de' MMM",
    MMMMEd => "E, d 'de' MMMM",
    "MMMMW-count-one" => "'semana' W 'de' MMMM",
    "MMMMW-count-other" => "'semana' W 'de' MMMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d 'de' MMM",
    MMMdd => "d 'de' MMM",
    MMd => "d/M",
    MMdd => "d/M",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmsvvvv => "h:mm:ss a (vvvv)",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "EEE, d/M/y",
    yMM => "M/y",
    yMMM => "MMM 'de' y",
    yMMMEd => "E, d 'de' MMM 'de' y",
    yMMMM => "MMMM 'de' y",
    yMMMMEd => "EEE, d 'de' MMMM 'de' y",
    yMMMMd => "d 'de' MMMM 'de' y",
    yMMMd => "d 'de' MMM 'de' y",
    yMd => "d/M/y",
    yQQQ => "QQQ 'de' y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "'semana' w 'de' Y",
    "yw-count-other" => "'semana' w 'de' Y",
  },
  code => "es-CO",
  date_format_full => "EEEE, d 'de' MMMM 'de' y",
  date_format_long => "d 'de' MMMM 'de' y",
  date_format_medium => "d/MM/y",
  date_format_short => "d/MM/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "mi\N{U+00e9}",
    "jue",
    "vie",
    "s\N{U+00e1}b",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "lunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "jueves",
    "viernes",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  day_stand_alone_abbreviated => [
    "lun.",
    "mar.",
    "mi\N{U+00e9}.",
    "jue.",
    "vie.",
    "s\N{U+00e1}b.",
    "dom.",
  ],
  day_stand_alone_narrow => [
    "l",
    "m",
    "m",
    "j",
    "v",
    "s",
    "d",
  ],
  day_stand_alone_wide => [
    "lunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "jueves",
    "viernes",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  era_abbreviated => [
    "a. C.",
    "d. C.",
  ],
  era_narrow => [
    "a. C.",
    "d. C.",
  ],
  era_wide => [
    "antes de Cristo",
    "despu\N{U+00e9}s de Cristo",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Spanish",
  month_format_abbreviated => [
    "ene.",
    "feb.",
    "mar.",
    "abr.",
    "may.",
    "jun.",
    "jul.",
    "ago.",
    "sep.",
    "oct.",
    "nov.",
    "dic.",
  ],
  month_format_narrow => [
    "E",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "enero",
    "febrero",
    "marzo",
    "abril",
    "mayo",
    "junio",
    "julio",
    "agosto",
    "septiembre",
    "octubre",
    "noviembre",
    "diciembre",
  ],
  month_stand_alone_abbreviated => [
    "ene.",
    "feb.",
    "mar.",
    "abr.",
    "may.",
    "jun.",
    "jul.",
    "ago.",
    "sept.",
    "oct.",
    "nov.",
    "dic.",
  ],
  month_stand_alone_narrow => [
    "E",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "enero",
    "febrero",
    "marzo",
    "abril",
    "mayo",
    "junio",
    "julio",
    "agosto",
    "septiembre",
    "octubre",
    "noviembre",
    "diciembre",
  ],
  name => "Spanish Colombia",
  native_language => "espa\N{U+00f1}ol",
  native_name => "espa\N{U+00f1}ol Colombia",
  native_script => undef,
  native_territory => "Colombia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => "Colombia",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 39,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/es-CO.pl <==
{
  am_pm_abbreviated => [
    "a.\N{U+202f}m.",
    "p.\N{U+202f}m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM 'de' y G",
    GyMMMEd => "E, d MMM 'de' y G",
    GyMMMM => "MMMM 'de' y G",
    GyMMMMEd => "E, d 'de' MMMM 'de' y G",
    GyMMMMd => "d 'de' MMMM 'de' y G",
    GyMMMd => "d 'de' MMM 'de' y G",
    GyMd => "d/M/y GGGGG",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmsvvvv => "HH:mm:ss vvvv",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d 'de' MMM",
    MMMMEd => "E, d 'de' MMMM",
    "MMMMW-count-one" => "'semana' W 'de' MMMM",
    "MMMMW-count-other" => "'semana' W 'de' MMMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d 'de' MMM",
    MMMdd => "d 'de' MMM",
    MMd => "d/M",
    MMdd => "d/M",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmsvvvv => "h:mm:ss\N{U+202f}a (vvvv)",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "EEE, d/M/y",
    yMM => "M/y",
    yMMM => "MMM 'de' y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM 'de' y",
    yMMMMEd => "EEE, d 'de' MMMM 'de' y",
    yMMMMd => "d 'de' MMMM 'de' y",
    yMMMd => "d 'de' MMM 'de' y",
    yMd => "d/M/y",
    yQQQ => "QQQ 'de' y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "'semana' w 'de' Y",
    "yw-count-other" => "'semana' w 'de' Y",
  },
  code => "es-CO",
  date_format_full => "EEEE, d 'de' MMMM 'de' y",
  date_format_long => "d 'de' MMMM 'de' y",
  date_format_medium => "d/MM/y",
  date_format_short => "d/MM/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "mi\N{U+00e9}",
    "jue",
    "vie",
    "s\N{U+00e1}b",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "m",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "lunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "jueves",
    "viernes",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  day_stand_alone_abbreviated => [
    "lun",
    "mar",
    "mi\N{U+00e9}",
    "jue",
    "vie",
    "s\N{U+00e1}b",
    "dom",
  ],
  day_stand_alone_narrow => [
    "l",
    "m",
    "m",
    "j",
    "v",
    "s",
    "d",
  ],
  day_stand_alone_wide => [
    "lunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "jueves",
    "viernes",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  era_abbreviated => [
    "a.C.",
    "d.C.",
  ],
  era_narrow => [
    "a.C.",
    "d.C.",
  ],
  era_wide => [
    "antes de Cristo",
    "despu\N{U+00e9}s de Cristo",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Spanish",
  month_format_abbreviated => [
    "ene",
    "feb",
    "mar",
    "abr",
    "may",
    "jun",
    "jul",
    "ago",
    "sept",
    "oct",
    "nov",
    "dic",
  ],
  month_format_narrow => [
    "E",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "enero",
    "febrero",
    "marzo",
    "abril",
    "mayo",
    "junio",
    "julio",
    "agosto",
    "septiembre",
    "octubre",
    "noviembre",
    "diciembre",
  ],
  month_stand_alone_abbreviated => [
    "ene.",
    "feb.",
    "mar.",
    "abr.",
    "may.",
    "jun.",
    "jul.",
    "ago.",
    "sept.",
    "oct.",
    "nov.",
    "dic.",
  ],
  month_stand_alone_narrow => [
    "E",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "enero",
    "febrero",
    "marzo",
    "abril",
    "mayo",
    "junio",
    "julio",
    "agosto",
    "septiembre",
    "octubre",
    "noviembre",
    "diciembre",
  ],
  name => "Spanish Colombia",
  native_language => "espa\N{U+00f1}ol",
  native_name => "espa\N{U+00f1}ol Colombia",
  native_script => undef,
  native_territory => "Colombia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => "Colombia",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => "44.1",
}
